Output
======

.. currentmodule:: nexoclom

.. autoclass:: Output
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Output.determine_filename
      ~Output.driver
      ~Output.restore
      ~Output.save
      ~Output.source_distribution
      ~Output.stream_driver

   .. rubric:: Methods Documentation

   .. automethod:: determine_filename
   .. automethod:: driver
   .. automethod:: restore
   .. automethod:: save
   .. automethod:: source_distribution
   .. automethod:: stream_driver
